<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package WordPress
 * @subpackage Weeland
 * @since 1.0
 * @version 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
  <meta charset="<?php bloginfo( 'charset' ); ?>">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <link rel="profile" href="http://gmpg.org/xfn/11">

  <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

  <?php wp_body_open(); ?>

  <div id="page" class="hfeed site">

    <div id="search-modal" class="search-modal">
      <?php get_search_form(); ?>
      <a href="#" id="close-search-modal" class="close-search-modal"><?php weeland_the_theme_svg( 'cross' ); ?></a>
    </div>

    <nav class="mobile-menu-wrapper">

      <ul class="mobile-menu">

      <?php
      if ( has_nav_menu( 'primary' ) ) {

        wp_nav_menu(
          array(
            'container'  => '',
            'items_wrap' => '%3$s',
            'theme_location' => 'primary',
            'show_sub_menu_icons' => true
          )
        );

      } else {

        wp_list_pages(
          array(
            'match_menu_classes' => true,
            'show_sub_menu_icons' => true,
            'title_li' => false,
            'walker'   => new Weeland_Walker_Page(),
          )
        );

      }
      ?>

      </ul>

      <?php echo get_search_form( false ); ?>

    </nav><!-- .mobile-menu-wrapper -->

    <div id="sidebar" class="sidebar">
      <div class="sidebar-inner">

        <div class="mobile-toggle">
          <a href="#" id="nav-toggle" class="nav-toggle"><i class="menu-icon"></i></a>
        </div>

        <a href="#" id="search-toggle" class="search-toggle"><?php weeland_the_theme_svg( 'search' ); ?></a>

        <header class="sidebar-header">
          <div class="site-identity">
            <?php weeland_site_identity(); ?>
          </div>
        </header>

        <nav class="primary-menu-wrapper">

          <ul class="primary-menu">

          <?php
          if ( has_nav_menu( 'primary' ) ) {

            wp_nav_menu(
              array(
                'container'  => '',
                'items_wrap' => '%3$s',
                'theme_location' => 'primary',
                'show_sub_menu_icons' => true
              )
            );

          } else {

            wp_list_pages(
              array(
                'match_menu_classes' => true,
                'show_sub_menu_icons' => true,
                'title_li' => false,
                'walker'   => new Weeland_Walker_Page(),
              )
            );

          }
          ?>

          </ul>

        </nav><!-- .primary-menu-wrapper -->

        <footer class="sidebar-footer">

          <?php if ( has_nav_menu( 'social' ) ) { ?>

          <nav aria-label="<?php esc_attr_e( 'Social links', 'weeland' ); ?>" class="social-menu-wrapper">

            <ul class="social-menu sidebar-social">

              <?php
              wp_nav_menu(
                  array(
                      'theme_location'  => 'social',
                      'container'       => '',
                      'container_class' => '',
                      'items_wrap'      => '%3$s',
                      'menu_id'         => '',
                      'menu_class'      => '',
                      'depth'           => 1,
                      'link_before'     => '<span class="screen-reader-text">',
                      'link_after'      => '</span>',
                      'fallback_cb'     => '',
                  )
              );
              ?>

            </ul><!-- .sidebar-social -->

          </nav><!-- .social-menu-wrapper -->

          <?php } ?>

          <?php weeland_site_copyright( '<div class="site-copyright">', '</div>' ); ?>

        </footer>
      </div>
    </div>

    <div id="content" class="site-content">